==> chaosmesh-model-6.5.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosRuleFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosRuleFluentImpl<A extends PodHttpChaosRuleFluent<A>> extends BaseFluent<A> implements PodHttpChaosRuleFluent<A>{
  public PodHttpChaosRuleFluentImpl() {
  }
  public PodHttpChaosRuleFluentImpl(PodHttpChaosRule instance) {
    this.withActions(instance.getActions()); 
    this.withPort(instance.getPort()); 
    this.withSelector(instance.getSelector()); 
    this.withSource(instance.getSource()); 
    this.withTarget(instance.getTarget()); 
  }
  private PodHttpChaosActionsBuilder actions;
  private Integer port;
  private PodHttpChaosSelectorBuilder selector;
  private String source;
  private String target;
  
  /**
   * This method has been deprecated, please use method buildActions instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosActions getActions() {
    return this.actions!=null ?this.actions.build():null;
  }
  public PodHttpChaosActions buildActions() {
    return this.actions!=null ?this.actions.build():null;
  }
  public A withActions(PodHttpChaosActions actions) {
    _visitables.get("actions").remove(this.actions);
    if (actions!=null){ this.actions= new PodHttpChaosActionsBuilder(actions); _visitables.get("actions").add(this.actions);} else { this.actions = null; _visitables.get("actions").remove(this.actions); } return (A) this;
  }
  public Boolean hasActions() {
    return this.actions != null;
  }
  public PodHttpChaosRuleFluent.ActionsNested<A> withNewActions() {
    return new PodHttpChaosRuleFluentImpl.ActionsNestedImpl();
  }
  public PodHttpChaosRuleFluent.ActionsNested<A> withNewActionsLike(PodHttpChaosActions item) {
    return new PodHttpChaosRuleFluentImpl.ActionsNestedImpl(item);
  }
  public PodHttpChaosRuleFluent.ActionsNested<A> editActions() {
    return withNewActionsLike(getActions());
  }
  public PodHttpChaosRuleFluent.ActionsNested<A> editOrNewActions() {
    return withNewActionsLike(getActions() != null ? getActions(): new PodHttpChaosActionsBuilder().build());
  }
  public PodHttpChaosRuleFluent.ActionsNested<A> editOrNewActionsLike(PodHttpChaosActions item) {
    return withNewActionsLike(getActions() != null ? getActions(): item);
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosSelector getSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public PodHttpChaosSelector buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(PodHttpChaosSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new PodHttpChaosSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public Boolean hasSelector() {
    return this.selector != null;
  }
  public PodHttpChaosRuleFluent.SelectorNested<A> withNewSelector() {
    return new PodHttpChaosRuleFluentImpl.SelectorNestedImpl();
  }
  public PodHttpChaosRuleFluent.SelectorNested<A> withNewSelectorLike(PodHttpChaosSelector item) {
    return new PodHttpChaosRuleFluentImpl.SelectorNestedImpl(item);
  }
  public PodHttpChaosRuleFluent.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public PodHttpChaosRuleFluent.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new PodHttpChaosSelectorBuilder().build());
  }
  public PodHttpChaosRuleFluent.SelectorNested<A> editOrNewSelectorLike(PodHttpChaosSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public String getSource() {
    return this.source;
  }
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public String getTarget() {
    return this.target;
  }
  public A withTarget(String target) {
    this.target=target; return (A) this;
  }
  public Boolean hasTarget() {
    return this.target != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodHttpChaosRuleFluentImpl that = (PodHttpChaosRuleFluentImpl) o;
    if (actions != null ? !actions.equals(that.actions) :that.actions != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    if (source != null ? !source.equals(that.source) :that.source != null) return false;
    if (target != null ? !target.equals(that.target) :that.target != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(actions,  port,  selector,  source,  target,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (actions != null) { sb.append("actions:"); sb.append(actions + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (target != null) { sb.append("target:"); sb.append(target); }
    sb.append("}");
    return sb.toString();
  }
  class ActionsNestedImpl<N> extends PodHttpChaosActionsFluentImpl<PodHttpChaosRuleFluent.ActionsNested<N>> implements PodHttpChaosRuleFluent.ActionsNested<N>,Nested<N>{
    ActionsNestedImpl(PodHttpChaosActions item) {
      this.builder = new PodHttpChaosActionsBuilder(this, item);
    }
    ActionsNestedImpl() {
      this.builder = new PodHttpChaosActionsBuilder(this);
    }
    PodHttpChaosActionsBuilder builder;
    public N and() {
      return (N) PodHttpChaosRuleFluentImpl.this.withActions(builder.build());
    }
    public N endActions() {
      return and();
    }
    
  }
  class SelectorNestedImpl<N> extends PodHttpChaosSelectorFluentImpl<PodHttpChaosRuleFluent.SelectorNested<N>> implements PodHttpChaosRuleFluent.SelectorNested<N>,Nested<N>{
    SelectorNestedImpl(PodHttpChaosSelector item) {
      this.builder = new PodHttpChaosSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new PodHttpChaosSelectorBuilder(this);
    }
    PodHttpChaosSelectorBuilder builder;
    public N and() {
      return (N) PodHttpChaosRuleFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosRuleFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosRuleFluentImpl<A extends PodHttpChaosRuleFluent<A>> extends BaseFluent<A> implements PodHttpChaosRuleFluent<A>{
  public PodHttpChaosRuleFluentImpl() {
  }
  public PodHttpChaosRuleFluentImpl(PodHttpChaosRule instance) {
    if (instance != null) {
      this.withActions(instance.getActions());
      this.withPort(instance.getPort());
      this.withSelector(instance.getSelector());
      this.withSource(instance.getSource());
      this.withTarget(instance.getTarget());
    }
  }
  private PodHttpChaosActionsBuilder actions;
  private Integer port;
  private PodHttpChaosSelectorBuilder selector;
  private String source;
  private String target;
  
  /**
   * This method has been deprecated, please use method buildActions instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosActions getActions() {
    return this.actions!=null ?this.actions.build():null;
  }
  public PodHttpChaosActions buildActions() {
    return this.actions!=null ?this.actions.build():null;
  }
  public A withActions(PodHttpChaosActions actions) {
    _visitables.get("actions").remove(this.actions);
    if (actions!=null){ this.actions= new PodHttpChaosActionsBuilder(actions); _visitables.get("actions").add(this.actions);} else { this.actions = null; _visitables.get("actions").remove(this.actions); } return (A) this;
  }
  public Boolean hasActions() {
    return this.actions != null;
  }
  public PodHttpChaosRuleFluentImpl.ActionsNested<A> withNewActions() {
    return new PodHttpChaosRuleFluentImpl.ActionsNestedImpl();
  }
  public PodHttpChaosRuleFluentImpl.ActionsNested<A> withNewActionsLike(PodHttpChaosActions item) {
    return new PodHttpChaosRuleFluentImpl.ActionsNestedImpl(item);
  }
  public PodHttpChaosRuleFluentImpl.ActionsNested<A> editActions() {
    return withNewActionsLike(getActions());
  }
  public PodHttpChaosRuleFluentImpl.ActionsNested<A> editOrNewActions() {
    return withNewActionsLike(getActions() != null ? getActions(): new PodHttpChaosActionsBuilder().build());
  }
  public PodHttpChaosRuleFluentImpl.ActionsNested<A> editOrNewActionsLike(PodHttpChaosActions item) {
    return withNewActionsLike(getActions() != null ? getActions(): item);
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosSelector getSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public PodHttpChaosSelector buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(PodHttpChaosSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new PodHttpChaosSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public Boolean hasSelector() {
    return this.selector != null;
  }
  public PodHttpChaosRuleFluentImpl.SelectorNested<A> withNewSelector() {
    return new PodHttpChaosRuleFluentImpl.SelectorNestedImpl();
  }
  public PodHttpChaosRuleFluentImpl.SelectorNested<A> withNewSelectorLike(PodHttpChaosSelector item) {
    return new PodHttpChaosRuleFluentImpl.SelectorNestedImpl(item);
  }
  public PodHttpChaosRuleFluentImpl.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public PodHttpChaosRuleFluentImpl.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new PodHttpChaosSelectorBuilder().build());
  }
  public PodHttpChaosRuleFluentImpl.SelectorNested<A> editOrNewSelectorLike(PodHttpChaosSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public String getSource() {
    return this.source;
  }
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public String getTarget() {
    return this.target;
  }
  public A withTarget(String target) {
    this.target=target; return (A) this;
  }
  public Boolean hasTarget() {
    return this.target != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosRuleFluentImpl that = (PodHttpChaosRuleFluentImpl) o;
    if (!java.util.Objects.equals(actions, that.actions)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    if (!java.util.Objects.equals(selector, that.selector)) return false;

    if (!java.util.Objects.equals(source, that.source)) return false;

    if (!java.util.Objects.equals(target, that.target)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(actions,  port,  selector,  source,  target,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (actions != null) { sb.append("actions:"); sb.append(actions + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (target != null) { sb.append("target:"); sb.append(target); }
    sb.append("}");
    return sb.toString();
  }
  class ActionsNestedImpl<N> extends PodHttpChaosActionsFluentImpl<PodHttpChaosRuleFluentImpl.ActionsNested<N>> implements PodHttpChaosRuleFluentImpl.ActionsNested<N>,Nested<N>{
    ActionsNestedImpl(PodHttpChaosActions item) {
      this.builder = new PodHttpChaosActionsBuilder(this, item);
    }
    ActionsNestedImpl() {
      this.builder = new PodHttpChaosActionsBuilder(this);
    }
    PodHttpChaosActionsBuilder builder;
    public N and() {
      return (N) PodHttpChaosRuleFluentImpl.this.withActions(builder.build());
    }
    public N endActions() {
      return and();
    }
    
  }
  class SelectorNestedImpl<N> extends PodHttpChaosSelectorFluentImpl<PodHttpChaosRuleFluentImpl.SelectorNested<N>> implements PodHttpChaosRuleFluentImpl.SelectorNested<N>,Nested<N>{
    SelectorNestedImpl(PodHttpChaosSelector item) {
      this.builder = new PodHttpChaosSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new PodHttpChaosSelectorBuilder(this);
    }
    PodHttpChaosSelectorBuilder builder;
    public N and() {
      return (N) PodHttpChaosRuleFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}
